@@ -237,7 +237,7 @@ class Image(InternalElement):
                 response.raise_for_status()
                 return await response.read()
 
-class FlashImage(Image):
+class FlashImage(Image, InternalElement):
     def toExternal(self):
         return External.FlashImage(
             imageId=self.imageId,
@@ -253,10 +253,19 @@ class FlashImage(Image):
             path=external_element.path
         )
 
+    @classmethod
+    def fromOriginalImage(cls, image_element: Image) -> "FlashImage":
+        return cls(
+            imageId=image_element.imageId,
+            url=image_element.url,
+            path=image_element.path
+        )
+
     def asDisplay(self) -> str:
         return "[闪照]"
 
 class Xml(InternalElement, ExternalElement):
+    type: "Xml"
     xml: str
 
     def toExternal(self):
@@ -270,6 +279,7 @@ class Xml(InternalElement, ExternalElement):
         return "[XML消息]"
 
 class Json(InternalElement, ExternalElement):
+    type = "Json"
     Json: str = Field(..., alias="json")
 
     def dict(self, *args, **kwargs):
@@ -289,6 +299,7 @@ class Json(InternalElement, ExternalElement):
         return external_element
 
 class App(InternalElement, ExternalElement):
+    type = "App"
     content: str
 
     def asDisplay(self) -> str:
@@ -310,6 +321,7 @@ class PokeMethods(Enum):
     FangDaZhao = "FangDaZhao"
 
 class Poke(InternalElement, ExternalElement):
+    type = "Poke"
     name: PokeMethods
 
     def asDisplay(self) -> str:
